diff --git a/lagebild/lagebild.js b/lagebild/lagebild.js
index 95a9427..8c04d38 100644
--- a/lagebild/lagebild.js
+++ b/lagebild/lagebild.js
@@ -625,8 +625,8 @@ var Lagebild = {
if (this.map) { this.map.remove(); this.map = null; }
this.map = L.map('map-container').setView([33.0, 48.0], 5);
- // Dark map tiles (CartoDB Dark Matter)
- L.tileLayer('https://{s}.basemaps.cartocdn.com/dark_all/{z}/{x}/{y}{r}.png', {
+ // Light map tiles (CartoDB Voyager)
+ L.tileLayer('https://{s}.basemaps.cartocdn.com/rastertiles/voyager/{z}/{x}/{y}{r}.png', {
attribution: '© OpenStreetMap © CARTO',
maxZoom: 19,
subdomains: 'abcd'